# coding: utf-8
"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set

    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

import pprint
import re  # noqa: F401
from typing import TYPE_CHECKING

import six

from cricket_cookie.openapi.configuration import Configuration

if TYPE_CHECKING:
    from datetime import datetime
    from cricket_cookie.openapi.models import *


class V1Resources(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'cpu': 'str',
        'extra': 'dict(str, str)',
        'gpu': 'str',
        'storage_gb': 'str'
    }

    attribute_map = {
        'cpu': 'cpu',
        'extra': 'extra',
        'gpu': 'gpu',
        'storage_gb': 'storageGb'
    }

    def __init__(self,
                 cpu: 'str' = None,
                 extra: 'dict(str, str)' = None,
                 gpu: 'str' = None,
                 storage_gb: 'str' = None,
                 _configuration=None):  # noqa: E501
        """V1Resources - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._cpu = None
        self._extra = None
        self._gpu = None
        self._storage_gb = None
        self.discriminator = None

        if cpu is not None:
            self.cpu = cpu
        if extra is not None:
            self.extra = extra
        if gpu is not None:
            self.gpu = gpu
        if storage_gb is not None:
            self.storage_gb = storage_gb

    @property
    def cpu(self) -> 'str':
        """Gets the cpu of this V1Resources.  # noqa: E501


        :return: The cpu of this V1Resources.  # noqa: E501
        :rtype: str
        """
        return self._cpu

    @cpu.setter
    def cpu(self, cpu: 'str'):
        """Sets the cpu of this V1Resources.


        :param cpu: The cpu of this V1Resources.  # noqa: E501
        :type: str
        """

        self._cpu = cpu

    @property
    def extra(self) -> 'dict(str, str)':
        """Gets the extra of this V1Resources.  # noqa: E501


        :return: The extra of this V1Resources.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._extra

    @extra.setter
    def extra(self, extra: 'dict(str, str)'):
        """Sets the extra of this V1Resources.


        :param extra: The extra of this V1Resources.  # noqa: E501
        :type: dict(str, str)
        """

        self._extra = extra

    @property
    def gpu(self) -> 'str':
        """Gets the gpu of this V1Resources.  # noqa: E501


        :return: The gpu of this V1Resources.  # noqa: E501
        :rtype: str
        """
        return self._gpu

    @gpu.setter
    def gpu(self, gpu: 'str'):
        """Sets the gpu of this V1Resources.


        :param gpu: The gpu of this V1Resources.  # noqa: E501
        :type: str
        """

        self._gpu = gpu

    @property
    def storage_gb(self) -> 'str':
        """Gets the storage_gb of this V1Resources.  # noqa: E501


        :return: The storage_gb of this V1Resources.  # noqa: E501
        :rtype: str
        """
        return self._storage_gb

    @storage_gb.setter
    def storage_gb(self, storage_gb: 'str'):
        """Sets the storage_gb of this V1Resources.


        :param storage_gb: The storage_gb of this V1Resources.  # noqa: E501
        :type: str
        """

        self._storage_gb = storage_gb

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict()
                        if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict") else item,
                        value.items()))
            else:
                result[attr] = value
        if issubclass(V1Resources, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'V1Resources') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, V1Resources):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other: 'V1Resources') -> bool:
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1Resources):
            return True

        return self.to_dict() != other.to_dict()
