# coding: utf-8
"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set

    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

import pprint
import re  # noqa: F401
from typing import TYPE_CHECKING

import six

from cricket_cookie.openapi.configuration import Configuration

if TYPE_CHECKING:
    from datetime import datetime
    from cricket_cookie.openapi.models import *


class V1ContainerResources(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'cpu_limits': 'str',
        'cpu_request': 'str',
        'memory_limits': 'str',
        'memory_request': 'str'
    }

    attribute_map = {
        'cpu_limits': 'cpuLimits',
        'cpu_request': 'cpuRequest',
        'memory_limits': 'memoryLimits',
        'memory_request': 'memoryRequest'
    }

    def __init__(self,
                 cpu_limits: 'str' = None,
                 cpu_request: 'str' = None,
                 memory_limits: 'str' = None,
                 memory_request: 'str' = None,
                 _configuration=None):  # noqa: E501
        """V1ContainerResources - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._cpu_limits = None
        self._cpu_request = None
        self._memory_limits = None
        self._memory_request = None
        self.discriminator = None

        if cpu_limits is not None:
            self.cpu_limits = cpu_limits
        if cpu_request is not None:
            self.cpu_request = cpu_request
        if memory_limits is not None:
            self.memory_limits = memory_limits
        if memory_request is not None:
            self.memory_request = memory_request

    @property
    def cpu_limits(self) -> 'str':
        """Gets the cpu_limits of this V1ContainerResources.  # noqa: E501


        :return: The cpu_limits of this V1ContainerResources.  # noqa: E501
        :rtype: str
        """
        return self._cpu_limits

    @cpu_limits.setter
    def cpu_limits(self, cpu_limits: 'str'):
        """Sets the cpu_limits of this V1ContainerResources.


        :param cpu_limits: The cpu_limits of this V1ContainerResources.  # noqa: E501
        :type: str
        """

        self._cpu_limits = cpu_limits

    @property
    def cpu_request(self) -> 'str':
        """Gets the cpu_request of this V1ContainerResources.  # noqa: E501


        :return: The cpu_request of this V1ContainerResources.  # noqa: E501
        :rtype: str
        """
        return self._cpu_request

    @cpu_request.setter
    def cpu_request(self, cpu_request: 'str'):
        """Sets the cpu_request of this V1ContainerResources.


        :param cpu_request: The cpu_request of this V1ContainerResources.  # noqa: E501
        :type: str
        """

        self._cpu_request = cpu_request

    @property
    def memory_limits(self) -> 'str':
        """Gets the memory_limits of this V1ContainerResources.  # noqa: E501


        :return: The memory_limits of this V1ContainerResources.  # noqa: E501
        :rtype: str
        """
        return self._memory_limits

    @memory_limits.setter
    def memory_limits(self, memory_limits: 'str'):
        """Sets the memory_limits of this V1ContainerResources.


        :param memory_limits: The memory_limits of this V1ContainerResources.  # noqa: E501
        :type: str
        """

        self._memory_limits = memory_limits

    @property
    def memory_request(self) -> 'str':
        """Gets the memory_request of this V1ContainerResources.  # noqa: E501


        :return: The memory_request of this V1ContainerResources.  # noqa: E501
        :rtype: str
        """
        return self._memory_request

    @memory_request.setter
    def memory_request(self, memory_request: 'str'):
        """Sets the memory_request of this V1ContainerResources.


        :param memory_request: The memory_request of this V1ContainerResources.  # noqa: E501
        :type: str
        """

        self._memory_request = memory_request

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict()
                        if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict") else item,
                        value.items()))
            else:
                result[attr] = value
        if issubclass(V1ContainerResources, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'V1ContainerResources') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, V1ContainerResources):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other: 'V1ContainerResources') -> bool:
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1ContainerResources):
            return True

        return self.to_dict() != other.to_dict()
